# Changelog

<!-- prettier-ignore -->
Name | PR | Developer | Date | Version
--- | --- | --- | --- | ---
🐛 Fix source unique together | [28](https://github.com/laminlabs/bionty/pull/28) | [sunnyosun](https://github.com/sunnyosun) | 2024-08-02 |
🚚 Let all link model fields start with `links_` | [19](https://github.com/laminlabs/bionty/pull/19) | [falexwolf](https://github.com/falexwolf) | 2024-08-02 |
🚚 Rename `.sources()` to `.list_source()` | [27](https://github.com/laminlabs/bionty/pull/27) | [sunnyosun](https://github.com/sunnyosun) | 2024-08-01 |
♻️ Refactor Source model | [25](https://github.com/laminlabs/bionty/pull/25) | [sunnyosun](https://github.com/sunnyosun) | 2024-08-01 |
🚚 Rename from_public to from_source | [24](https://github.com/laminlabs/bionty/pull/24) | [sunnyosun](https://github.com/sunnyosun) | 2024-08-01 |
🚚 Rename save_from_df to import_from_source | [23](https://github.com/laminlabs/bionty/pull/23) | [sunnyosun](https://github.com/sunnyosun) | 2024-07-31 |
🎨 Make `CellMarker.name` unique together with `organism` | [22](https://github.com/laminlabs/bionty/pull/22) | [sunnyosun](https://github.com/sunnyosun) | 2024-07-31 |
🐛 Fix add_ontology | [20](https://github.com/laminlabs/bionty/pull/20) | [sunnyosun](https://github.com/sunnyosun) | 2024-07-31 |
🐛 Fix core import and parents save | [18](https://github.com/laminlabs/bionty/pull/18) | [sunnyosun](https://github.com/sunnyosun) | 2024-07-30 |
🏗️  Integrate `lnschema-bionty` and `bionty-base` into `bionty` | [17](https://github.com/laminlabs/bionty/pull/17) | [sunnyosun](https://github.com/sunnyosun) | 2024-07-29 | 0.46.0
🚚 Rename PublicSource to Source | [16](https://github.com/laminlabs/bionty/pull/16) | [sunnyosun](https://github.com/sunnyosun) | 2024-07-26 | 0.45.0
♻️ Rename Registry to Record | [15](https://github.com/laminlabs/bionty/pull/15) | [falexwolf](https://github.com/falexwolf) | 2024-07-17 |
🔇 Remove py warning | [14](https://github.com/laminlabs/bionty/pull/14) | [sunnyosun](https://github.com/sunnyosun) | 2024-03-27 | 0.42.4
🚚 Rename dev to core | [13](https://github.com/laminlabs/bionty/pull/13) | [sunnyosun](https://github.com/sunnyosun) | 2024-03-13 | 0.42.1
♻️ Simplify init | [12](https://github.com/laminlabs/bionty/pull/12) | [falexwolf](https://github.com/falexwolf) | 2024-03-08 | 0.42.0
🚑️ Fix reload | [11](https://github.com/laminlabs/bionty/pull/11) | [sunnyosun](https://github.com/sunnyosun) | 2024-03-07 |
🏗️ Enable `ln.connect()` in lamindb | [9](https://github.com/laminlabs/bionty/pull/9) | [falexwolf](https://github.com/falexwolf) | 2024-03-07 |
🚚 Rename dev to core | [8](https://github.com/laminlabs/bionty/pull/8) | [falexwolf](https://github.com/falexwolf) | 2024-02-29 |
📝 Updated landing page | [7](https://github.com/laminlabs/bionty/pull/7) | [sunnyosun](https://github.com/sunnyosun) | 2024-02-06 |
💚 Fix docs | [6](https://github.com/laminlabs/bionty/pull/6) | [sunnyosun](https://github.com/sunnyosun) | 2024-01-31 |
⬆️ Update lb | [5](https://github.com/laminlabs/bionty/pull/5) | [sunnyosun](https://github.com/sunnyosun) | 2024-01-31 | 0.40.2
👷 Upload docs | [4](https://github.com/laminlabs/bionty/pull/4) | [sunnyosun](https://github.com/sunnyosun) | 2024-01-31 | 0.40.1
💚 Fix docs | [3](https://github.com/laminlabs/bionty/pull/3) | [sunnyosun](https://github.com/sunnyosun) | 2024-01-30 |
📝 Updated readme | [2](https://github.com/laminlabs/bionty/pull/2) | [sunnyosun](https://github.com/sunnyosun) | 2024-01-30 |
🎨 Import orms from lb | [1](https://github.com/laminlabs/bionty/pull/1) | [sunnyosun](https://github.com/sunnyosun) | 2024-01-30 |
